@@ -9,6 +9,7 @@ from django.template import Template, Context
 from django.conf import settings
 
 from tethys_apps.terminal_colors import TerminalColors
+from .docker_commands import *
 
 # Module level variables
 GEN_SETTINGS_OPTION = 'settings'
@@ -158,6 +159,32 @@ def manage_command(args):
             pass
 
 
+def docker_command(args):
+    """
+    Docker management commands.
+    """
+    if args.command == 'init':
+        docker_init(container=args.container, defaults=args.defaults)
+
+    elif args.command == 'start':
+        docker_start(container=args.container)
+
+    elif args.command == 'stop':
+        docker_stop(container=args.container)
+
+    elif args.command == 'status':
+        docker_status()
+
+    elif args.command == 'update':
+        docker_update(container=args.container, defaults=args.defaults)
+
+    elif args.command == 'remove':
+        docker_remove(container=args.container)
+
+    elif args.command == 'ip':
+        docker_ip()
+
+
 def syncstores_command(args):
     """
     Sync persistent stores.
@@ -249,6 +276,19 @@ def tethys_command():
     syncstores_parser.add_argument('-m', '--manage', help='Absolute path to manage.py for Tethys Platform installation.')
     syncstores_parser.set_defaults(func=syncstores_command, refresh=False, firstime=False)
 
+    # Setup the docker commands
+    docker_parser = subparsers.add_parser('docker', help="Management commands for the Tethys Docker containers.")
+    docker_parser.add_argument('command',
+                               help='Docker command to run.',
+                               choices=['init', 'start', 'stop', 'status', 'update', 'remove', 'ip'])
+    docker_parser.add_argument('-d', '--defaults',
+                               action='store_true',
+                               dest='defaults',
+                               help="Run command without prompting without interactive input, using defaults instead.")
+    docker_parser.add_argument('-c', '--container',
+                               help="Execute the command only on the given container.",
+                               choices=[POSTGIS_INPUT, GEOSERVER_INPUT, N52WPS_INPUT])
+    docker_parser.set_defaults(func=docker_command)
 
     # Parse the args and call the default function
     args = parser.parse_args()
